import { buildUUID } from '../../../utils/uuid';
import { ApiActionPage } from '../../model/baseModel';
import { WmsItemPageListGetResultModel, WmsItemPageParams } from '../model/warehoueseModel';
import { Api, genAction, genActionPage } from '../system';
import { useUserStore } from '/@/store/modules/user';
import { defHttp } from '/@/utils/http/axios';
import { isNullOrEmpty } from '/@/utils/is';

/*
 * 获取实时库存分页列表
 */
export const getWmsItemListByPage = async (params: any) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let res = false;
  let sqlcmd = '1=1';
  if (params?.SN != undefined && params?.SN != '') {
    sqlcmd += " And SN like '%" + params?.SN + "%'";
    res = true;
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
    res = true;
  }
  if (params?.WH_CODE != undefined && params?.WH_CODE != '') {
    sqlcmd += " And WH_CODE = '" + params?.WH_CODE + "'";
    res = true;
  }
  if (params?.SHELF_CODE != undefined && params?.SHELF_CODE != '') {
    sqlcmd += " And SHELF_CODE like '" + params?.SHELF_CODE + "%'";
    res = true;
  }
  if (params?.LOCATION_CODE != undefined && params?.LOCATION_CODE != '') {
    sqlcmd += " And LOCATION_CODE like '" + params?.LOCATION_CODE + "%'";
    res = true;
  }
  if (params?.STATUS != undefined && params?.STATUS != '') {
    sqlcmd += " And STATUS IN (" + params?.STATUS + ")";
  }
  if (!res) {
    const date = new Date();//当前系统时间
    const thisdate = date.toLocaleString();//转化当天时间
    date.setDate(date.getDate() - 1)
    const lastdate = date.toLocaleString();//昨天时间
    sqlcmd += " And '" + lastdate + "'<UPDATE_TIME AND UPDATE_TIME<'" + thisdate + "'"
  }
  var option = {
    UserId: useUserStore().getUserInfo.userId as string,
    ByOrg: true,
    OrgCode: useUserStore().getUserInfo.orgCode as string
  }
  var v_item = "V_WMS_ITEM"
  switch (option.OrgCode) {
    case "XCSJ":
      v_item = "V_WMS_ITEM_X";
      break;
    case "DGXC":
      v_item = "V_WMS_ITEM_D";
      break;
    case "AHXC":
      v_item = "V_WMS_ITEM_A";
      break;
    case "YTXC":
      v_item = "V_WMS_ITEM_Y";
      break;
  }
  // const rParams = genActionPage('V_WMS_ITEM', sqlcmd, params.page, params.pageSize,option);
  // return getWmsItemListByPageAsync(rParams);
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction(v_item, {
      QueryAble_T: '',
      where: sqlcmd,
      order: order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
    });
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getWmsItemListByPageAsync(usParams);
  } else {
    const usParams = genAction(v_item, {
      QueryAble_T: '',
      where: sqlcmd,
      option
    }, option);
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getWmsItemListByPageAsync(usParams);
  }
};
async function getWmsItemListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params, timeout: 10000 * 30 },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }

  return model;
}
/*
 * 获取库存汇总分页列表
 */
export const getWmsItemSumByPage = async (params: any) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.WH_CODE != undefined && params?.WH_CODE != '') {
    sqlcmd += " And WH_CODE like '%" + params?.WH_CODE + "%'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  var option = {
    UserId: useUserStore().getUserInfo.userId as string,
    ByOrg: true,
    OrgCode: useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('V_WMS_ITEM_SUM', {
      QueryAble_T: '',
      where: sqlcmd,
      order: order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      }
      , option
    }, option);
    return getWmsItemSumByPageAsync(usParams);
  } else {
    const usParams = genAction('V_WMS_ITEM_SUM', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },
      option);
    return getWmsItemSumByPageAsync(usParams);
  }
  // const rParams = genActionPage('V_WMS_ITEM_SUM', sqlcmd, params.page, params.pageSize,option);
  // return getWmsItemSumByPageAsync(rParams);
};
async function getWmsItemSumByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, timeout: 60 * 10000, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }

  return model;
}
//下拉列表
// STATUSs 仓库状态
export const optionsListApi = async (params: Recordable) => {
  const usParams = genAction('WMS_ITEM+STATUSs', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
};